@@ -15,48 +15,50 @@ swap_class <- function(x, new_class) {
 setClassUnion("NULLorCharacter", c("NULL", "character"))
 
 #' tinytable S4 class
-#' 
+#'
 #' @keywords internal
 #' @export
 setClass(
-    Class = "tinytable",
-    slots = representation(
-        table_dataframe = "data.frame",
-        table_string = "character",
-        data = "data.frame",
-        caption = "character",
-        width = "numeric",
-        width_cols = "numeric",
-        notes = "list",
-        theme = "list",
-        placement = "character",
-        body = "character",
-        nrow = "numeric",
-        ncol = "numeric",
-        nhead = "numeric",
-        ngroupi = "numeric",
-        ngroupj = "numeric",
-        group_i_idx = "numeric",
-        names = "NULLorCharacter",
-        output = "character",
-        output_dir = "character",
-        id = "character",
-        bootstrap_class = "character",
-        bootstrap_css_rule = "character",
-        css = "data.frame",
-        style = "data.frame",
-        lazy_format = "list",
-        lazy_group = "list",
-        lazy_style = "list",
-        lazy_plot = "list",
-        lazy_finalize = "list",
-        lazy_theme = "list",
-        portable = "logical"
-        )
+  Class = "tinytable",
+  slots = representation(
+    body = "character",
+    bootstrap_class = "character",
+    bootstrap_css_rule = "character",
+    caption = "character",
+    css = "data.frame",
+    data = "data.frame",
+    group_index_i = "numeric",
+    group_n_i = "numeric",
+    group_n_j = "numeric",
+    id = "character",
+    lazy_finalize = "list",
+    lazy_format = "list",
+    lazy_group = "list",
+    lazy_plot = "list",
+    lazy_style = "list",
+    lazy_theme = "list",
+    names = "NULLorCharacter",
+    ncol = "numeric",
+    nhead = "numeric",
+    notes = "list",
+    nrow = "numeric",
+    output = "character",
+    output_dir = "character",
+    placement = "character",
+    portable = "logical",
+    style = "data.frame",
+    style_caption = "list",
+    style_notes = "list",
+    table_dataframe = "data.frame",
+    table_string = "character",
+    theme = "list",
+    width = "numeric",
+    width_cols = "numeric"
+  )
 )
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setMethod("initialize", "tinytable", function(
@@ -76,8 +78,8 @@ setMethod("initialize", "tinytable", function(
   .Object@nrow <- nrow(.Object@data)
   .Object@ncol <- ncol(.Object@data)
   .Object@nhead <- if (is.null(colnames(data))) 0 else 1
-  .Object@ngroupi <- 0
-  .Object@ngroupj <- 0
+  .Object@group_n_i <- 0
+  .Object@group_n_j <- 0
   .Object@names <- if (is.null(colnames(data))) character() else colnames(data)
   .Object@id <- get_id("tinytable_")
   .Object@output <- "tinytable"
@@ -95,85 +97,95 @@ setMethod("initialize", "tinytable", function(
 })
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
-setMethod("nrow", "tinytable", function(x) return(x@nrow))
+setMethod("nrow", "tinytable", function(x) {
+  return(x@nrow)
+})
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
-setMethod("ncol", "tinytable", function(x) return(x@ncol))
+setMethod("ncol", "tinytable", function(x) {
+  return(x@ncol)
+})
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 #' @export
-setMethod("colnames", "tinytable", function(x) return(x@names))
+setMethod("colnames", "tinytable", function(x) {
+  return(x@names)
+})
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 #' @export
-setMethod("names", "tinytable", function(x) return(x@names))
+setMethod("names", "tinytable", function(x) {
+  return(x@names)
+})
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 #' @export
 setReplaceMethod("colnames",
-                 signature = "tinytable", 
-                 definition = function(x, value) {
-                   # Issue #306
-                   if (length(value) == 0) value <- NULL
-                   if (!is.null(value)) {
-                     assert_character(value, len = length(x@names))
-                   } else {
-                     if (x@nhead == 1) x@nhead <- 0
-                   }
-                   x@names <- value
-                   return(x)
-                 }
-)
+  signature = "tinytable",
+  definition = function(x, value) {
+    # Issue #306
+    if (length(value) == 0) value <- NULL
+    if (!is.null(value)) {
+      assert_character(value, len = length(x@names))
+    } else {
+      if (x@nhead == 1) x@nhead <- 0
+    }
+    x@names <- value
+    return(x)
+  })
 
 #' Method for a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 #' @export
 setReplaceMethod("names",
-                 signature = "tinytable", 
-                 definition = function(x, value) {
-                   # Issue #306
-                   if (length(value) == 0) value <- NULL
-                   if (!is.null(value)) {
-                     assert_character(value, len = length(x@names))
-                   } else {
-                     if (x@nhead == 1) x@nhead <- 0
-                   }
-                   x@names <- value
-                   return(x)
-                 }
-)
+  signature = "tinytable",
+  definition = function(x, value) {
+    # Issue #306
+    if (length(value) == 0) value <- NULL
+    if (!is.null(value)) {
+      assert_character(value, len = length(x@names))
+    } else {
+      if (x@nhead == 1) x@nhead <- 0
+    }
+    x@names <- value
+    return(x)
+  })
 
 #' Dimensions a tinytable S4 object
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
-setMethod("dim", "tinytable", function(x) return(c(x@nrow, x@ncol)))
+setMethod("dim", "tinytable", function(x) {
+  return(c(x@nrow, x@ncol))
+})
 
 #' Column names of a tinytable
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
-setMethod("names", "tinytable", function(x) return(x@names))
+setMethod("names", "tinytable", function(x) {
+  return(x@names)
+})
 
 #' Convert a tinytable S4 object to a string
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setMethod("as.character", "tinytable", function(x) {
@@ -188,7 +200,7 @@ setClass("tinytable_grid", contains = "tinytable")
 setClass("tinytable_dataframe", contains = "tinytable")
 
 #' Apply style settings to a tinytable
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setGeneric(
@@ -197,7 +209,7 @@ setGeneric(
 )
 
 #' Apply group settings to a tinytable
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setGeneric(
@@ -206,7 +218,7 @@ setGeneric(
 )
 
 #' Apply group settings to a tinytable
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setGeneric(
@@ -215,12 +227,10 @@ setGeneric(
 )
 
 #' Apply final settings to a tinytable
-#' 
+#'
 #' @inheritParams tt
 #' @keywords internal
 setGeneric(
   name = "finalize",
   def = function(x, ...) standardGeneric("finalize")
 )
-
-
